@@ -1,8 +1,8 @@
 !== Monitor of CPU TIME
 !
 ! Authors::   Yasuhiro MORIKAWA
-! Version::   $Id: dc_clock.f90,v 1.8 2006/12/25 14:27:54 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070305 $
+! Version::   $Id: dc_clock.f90,v 1.10 2007/03/21 06:58:01 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070427 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2006. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -157,8 +157,8 @@ module dc_clock
 
 
   character(*), parameter:: version = &
-    & '$Name: gt4f90io-20070305 $' // &
-    & '$Id: dc_clock.f90,v 1.8 2006/12/25 14:27:54 morikawa Exp $'
+    & '$Name: gt4f90io-20070427 $' // &
+    & '$Id: dc_clock.f90,v 1.10 2007/03/21 06:58:01 morikawa Exp $'
 
 contains
 
@@ -268,6 +268,7 @@ contains
     use dc_error, only: StoreError, DC_ENOTINIT, DC_NOERR
     use dc_date, only: EvalSec, assignment(=), operator(+), operator(-)
     use dc_date_types, only: DC_DIFFTIME
+    use dc_types, only: DP
     implicit none
     type(CLOCK), intent(inout) :: clk
     logical, intent(out), optional:: err
@@ -285,7 +286,7 @@ contains
       endsub_msg = 'Ignored because input argument was not initialized.'
       stat = DC_ENOTINIT
       goto 999
-    elseif (EvalSec(clk % start_time) < 0.0d0) then
+    elseif (EvalSec(clk % start_time) < 0.0_DP) then
       call MessageNotify('W', subname, 'Call Start before Stop in dc_clock.')
       endsub_msg = 'Ignored because input argument was not started.'
       goto 999
@@ -399,7 +400,7 @@ contains
     logical :: err
   continue
     call DCClockGetD(clk, result, err)
-    if (err) result = -1.0d0
+    if (err) result = -1.0_DP
   end function DCClockEvalSecD
 
   function DCClockToChar(clk) result(result)
@@ -444,6 +445,7 @@ contains
     use dc_string, only: Printf, toChar, CPrintf
     use dc_date, only: EvalSec, EvalDay, toChar
     use dc_error, only: StoreError, DC_ENOTINIT, DC_NOERR
+    use dc_types, only: DP
     implicit none
     type(CLOCK), intent(in) :: clk
     integer, intent(in), optional :: unit
@@ -469,7 +471,7 @@ contains
     end if
     call Printf(out_unit, &
       & '#<CLOCK:: @name=%c @clocking=%y @elapsed_time=%f sec. %c @start_date=%c>', &
-      & c1=trim(clk % name), l=(/EvalSec(clk % start_time) > 0.0d0/), &
+      & c1=trim(clk % name), l=(/EvalSec(clk % start_time) > 0.0_DP/), &
       & d=(/EvalSec(clk % elapsed_time)/), &
       & c2=trim(fit_unit_value(clk % elapsed_time)), &
       & c3=trim(toChar(clk % start_date)))
@@ -613,6 +615,7 @@ contains
     use dc_types, only: DP, TOKEN
     use dc_date_types, only: DC_DIFFTIME
     use dc_date, only: EvalDay, EvalHour, EvalMin, EvalSec
+    use dc_types, only: DP
     implicit none
     character(TOKEN) :: result
     type(DC_DIFFTIME), intent(in) :: diff
@@ -620,13 +623,13 @@ contains
     real(DP) :: value
     character(TOKEN) :: cval
   continue
-    if (EvalDay(diff) > 1.0d0) then
+    if (EvalDay(diff) > 1.0_DP) then
       unit = ' days'
       value = EvalDay(diff)
-    elseif (EvalHour(diff) > 1.0d0) then
+    elseif (EvalHour(diff) > 1.0_DP) then
       unit = ' hrs.'
       value = EvalHour(diff)
-    elseif (EvalMin(diff) > 1.0d0) then
+    elseif (EvalMin(diff) > 1.0_DP) then
       unit = ' minutes'
       value = EvalMin(diff)
     else
@@ -745,11 +748,18 @@ contains
     !=== ץबλޤǤͽ¬ CPU , ɽ
     !
     ! CLOCK ѿ *clk*  *progress* , ץब
-    ! λޤǤͽ¬ CPU , ɽޤ.
+    ! λޤǤͽ¬ CPU , ʲΤ褦ɽޤ.
+    !
+    !     ########## PREDICTION OF CALCULATION ###########
+    !     Start Date             2007-03-08T16:49:25+09:00
+    !     Current Date           2007-03-08T16:49:27+09:00
+    !     Progress     66.67%  [****************         ]
+    !     Remaining CPU TIME      0.100000E+01
+    !     Completion Date        2007-03-08T16:49:28+09:00
     !
     ! 2Ǥ *progress* ˤ 0  1 ޤǤͤͿƤ.
     ! ץγϻ 0, λ 1 Ȥޤ. (㤨,
-    ! ץब礦Ⱦʬλˤ 0.5 Ϳޤ).
+    ! ץबȾʬʤˤ 0.5 Ϳޤ).
     !
     ! ǹԤͽ¬פȤ, ޤǤηв֤
     ! λץʬ̤ñʥ르ꥺǳФƤ
